<?php

/*-----------------------------------------------------------------------------------*/
/* Enqueu scripts */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('vivace_enqueue_scripts')) {

	function vivace_enqueue_scripts() {

		wp_deregister_style('avventura-lite-style' );
		wp_enqueue_style('avventura-lite-parent-style' , get_template_directory_uri() . '/style.css' ); 
		wp_enqueue_style('vivace-style' , get_stylesheet_directory_uri() . '/style.css' ); 
		wp_enqueue_script('vivace-template',get_stylesheet_directory_uri() . '/assets/js/template.js',array('jquery'), '1.0.0', TRUE );
	
		wp_enqueue_style(
			'vivace-' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')),
			get_template_directory_uri() . '/assets/skins/' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')) . '.css',
			array( 'vivace-style' ),
			'1.0.0'
		); 

		wp_enqueue_style(
			'vivace-theme-' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')),
			get_stylesheet_directory_uri() . '/assets/skins/' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')) . '.css',
			array( 'vivace-style' ),
			'1.0.0'
		); 

		$googleFontsArgs = array(
			'family' =>	str_replace('|', '%7C','Poppins:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i'),
			'subset' =>	'latin,latin-ext'
		);
		
		wp_deregister_style('google-fonts');
		wp_enqueue_style('google-fonts', add_query_arg ( $googleFontsArgs, "https://fonts.googleapis.com/css" ), array(), '1.0.0' );

	}
	
	add_action( 'wp_enqueue_scripts', 'vivace_enqueue_scripts', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Replace hooks */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('vivace_replace_hooks')) {

	function vivace_replace_hooks() {
		remove_action('avventura_lite_mobile_menu', 'avventura_lite_mobile_menu_function' );
		remove_action('avventura_lite_top_sidebar', 'avventura_lite_top_sidebar_function' );
	}
	
	add_action('init','vivace_replace_hooks',9999);

}

/*-----------------------------------------------------------------------------------*/
/* Replace hooks */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('vivace_mobile_menu_function')) {

	function vivace_mobile_menu_function() {

?>

        <div id="sidebar-wrapper">
            
            <div id="scroll-sidebar" class="clearfix">

                <div class="wrap">

                	<a class="mobile-navigation" href="#modal-sidebar">
                		<i class="fa fa-times open"></i>
                	</a>
                	
	                <div class="mobilemenu-box">
						<nav id="mobilemenu"><?php wp_nav_menu( array('theme_location' => 'main-menu', 'container' => 'false','depth' => 3  )); ?></nav> 
					</div>
                
            	</div>

            </div>
        
        </div>
        
<?php
	
	}

	add_action( 'vivace_mobile_menu', 'vivace_mobile_menu_function' );

}

/*-----------------------------------------------------------------------------------*/
/* Replace hooks */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('vivace_top_sidebar_function')) {

	function vivace_top_sidebar_function() {

		$isWidget = is_active_sidebar('avventura-lite-top-widget-area') ? TRUE : FALSE;
		$isPosition = ( !avventura_lite_setting('avventura_lite_homepage_slideshow_position') || avventura_lite_setting('avventura_lite_homepage_slideshow_position') === 'top' ) ? TRUE : FALSE;
		$isHome = ( !avventura_lite_setting('avventura_lite_homepage_slideshow') || avventura_lite_setting('avventura_lite_homepage_slideshow') === 'on') ? TRUE : FALSE;
		$isSlideshow = ( $isHome == TRUE && $isPosition == TRUE && ( is_home() || is_front_page()) ) ? TRUE : FALSE;

		if ( $isWidget || $isSlideshow ) : 
	
	?>
			
			<div id="top_sidebar" class="sidebar-area">
			
				<?php 
						
					if ( $isSlideshow == TRUE )
						do_action('avventura_lite_slick_slider', 2 , 'avventura_lite_slick_small');
							
					if ( $isWidget == TRUE )
						dynamic_sidebar('avventura-lite-top-widget-area');
                    	
				?>
                			
			</div>
				
	<?php 
	
		endif;
		
	}

	add_action( 'avventura_lite_top_sidebar', 'vivace_top_sidebar_function' );

}

/*-----------------------------------------------------------------------------------*/
/* CUSTOMIZE */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('vivace_customize_register')) {

	function vivace_customize_register( $wp_customize ) {
	
		$wp_customize->remove_setting( 'avventura_lite_sticky_header');
		$wp_customize->remove_control( 'avventura_lite_sticky_header');
		$wp_customize->remove_setting( 'avventura_lite_header_layout');
		$wp_customize->remove_control( 'avventura_lite_header_layout');
		$wp_customize->remove_control( 'avventura_lite_post_icon');
		
		$wp_customize->add_control( 'avventura_lite_post_icon' , array(
			'type' => 'select',
			'section' => 'settings_section',
			'label' => esc_html__('Post Icon', 'vivace'),
			'description' => esc_html__('Do you want to display the post icon?', 'vivace'),
			'choices'  => array (
				'off' => esc_html__( 'No',   'vivace'),
				'on' => esc_html__( 'Yes', 'vivace'),
			),
		));

		function vivace_select_sanitize ($value, $setting) {
		
			global $wp_customize;
					
			$control = $wp_customize->get_control( $setting->id );
				 
			if ( array_key_exists( $value, $control->choices ) ) {
					
				return $value;
					
			} else {
					
				return $setting->default;
					
			}
			
		}

	}
	
	add_action( 'customize_register', 'vivace_customize_register', 11 );

}

/*-----------------------------------------------------------------------------------*/
/* Theme setup */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('vivace_theme_setup')) {

	function vivace_theme_setup() {

		load_child_theme_textdomain( 'vivace', get_stylesheet_directory() . '/languages' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/functions/function-style.php' );

	}

	add_action( 'after_setup_theme', 'vivace_theme_setup', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Theme setup */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('vivace_widgets_init')) {

	function vivace_widgets_init() {

		unregister_sidebar('avventura-lite-scroll-widget-area');

	}

	add_action( 'widgets_init', 'vivace_widgets_init', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Function to check if the searchform.php file is loaded inside a sidebar area */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'vivace_is_sidebar_area' ) ) {

	function vivace_is_sidebar_area() {

		$result = false;

		$activeSidebars = array(
			'avventura_lite_side_sidebar',
			'avventura_lite_top_sidebar',
			'avventura_lite_header_sidebar',
			'avventura_lite_bottom_sidebar',
			'avventura_lite_ooter_sidebar'
		);

		if ( in_array(current_filter(), $activeSidebars) ) {
			$result = true;
		}

		return $result;

	}

}

?>